::: sleeplab_format.models
    options:
        members:
            - Dataset
            - Series
            - Subject
            - SubjectMetadata
            - SampleArray
            - ArrayAttributes
            - BaseAnnotations
            - Annotations
            - AASMEvents
            - Hypnogram
            - Sex
            - AASMEvent
            - AASMSleepStage
